@@ -195,7 +195,7 @@ class Exchange():
         if self.backend_name == "SIESTA":
             syms = self.atoms.get_chemical_symbols()
             for iatom, orbs in self.labels.items():
-                if syms[iatom] in self.include_orbs:
+                if (self.include_orbs is not None) and syms[iatom] in self.include_orbs:
                     mmat, reduced_orbs = map_orbs_matrix(
                         orbs,
                          spinor=not (self._is_collinear),
@@ -289,7 +289,8 @@ class ExchangeNCL(Exchange):
 
     def get_H_atom(self, iatom):
         orbs = self.iorb(iatom)
-        return self.HR0[self.orb_slice[iatom], self.orb_slice[iatom]]
+        #return self.HR0[self.orb_slice[iatom], self.orb_slice[iatom]]
+        return self.HR0[np.ix_(orbs, orbs)]
 
     def get_P_iatom(self, iatom):
         """ Calculate the norm of the Hamiltonian vector.
@@ -316,8 +317,8 @@ class ExchangeNCL(Exchange):
         """
         orbi = self.iorb(iatom)
         orbj = self.iorb(jatom)
-        # return GR[np.ix_(orbi, orbj)]
-        return GR[self.orb_slice[iatom], self.orb_slice[jatom]]
+        return GR[np.ix_(orbi, orbj)]
+        #return GR[self.orb_slice[iatom], self.orb_slice[jatom]]
 
     def get_A_ijR(self, G, R, iatom, jatom):
         """ calculate A from G for a energy slice (de).
