@@ -238,6 +238,7 @@ Warning: Please check if the noise level of Wannier function Hamiltonian to make
 
 def gen_exchange_siesta(fdf_fname,
                         magnetic_elements=[],
+                        include_orbs=None,
                         kmesh=[5, 5, 5],
                         emin=-12.0,
                         emax=0.0,
@@ -279,6 +280,7 @@ def gen_exchange_siesta(fdf_fname,
             basis=basis,
             efermi=0.0,
             magnetic_elements=magnetic_elements,
+            include_orbs=include_orbs,
             kmesh=kmesh,
             emin=emin,
             emax=emax,
@@ -314,6 +316,7 @@ def gen_exchange_siesta(fdf_fname,
                                basis=basis,
                                efermi=0.0,
                                magnetic_elements=magnetic_elements,
+                               include_orbs=include_orbs,
                                kmesh=kmesh,
                                emin=emin,
                                emax=emax,
@@ -348,6 +351,7 @@ Warning: The DMI component parallel to the spin orientation, the Jani which has
                                basis=basis,
                                efermi=0.0,
                                magnetic_elements=magnetic_elements,
+                               include_orbs=include_orbs,
                                kmesh=kmesh,
                                emin=emin,
                                emax=emax,
